DATA = [
    ## Google
    '72.14.199.0/25',
    '209.85.238.0/25',

    ## Yahoo! Japan
    '124.83.159.146/31',
    '124.83.159.148/30',
    '124.83.159.152/29',
    '124.83.159.160/28',
    '124.83.159.176/29',
    '124.83.159.184/31',

    ## DeNA
    '202.238.103.126',
    '202.213.221.97',

    ## F-route
    '60.43.36.253',

    ## livedoor
    '203.104.254.0/24',

    ## goo
    '210.150.10.32/27',

    ## baidu
    '119.63.195.0/24',
]
